function g2_norm = regular_g2(I)
% computes the g2 autocorrelation.
% This approach is much longer than g2.m, which is the fft version.
% input must be the 2D array of time series for all pixels e.g. of
% dimensions [pixels,frames].

try   
    I = double(I); % Convert to double if not already double. isequal(double(I),im2double(I)*65535) = 1
    pixels = size(I,1);
    frames = size(I,2);
    I_padded = zeros(pixels,frames); % Zero pad the intensity time series for the for loop dot product.
    I_padded = cat(2,I,I_padded);
    g2_norm = zeros(pixels,frames*2);
    intensity_norm = mean(I_padded(:,1:end/2),2); % Intensity normalisation (exclude zeros)
    if intensity_norm == 0
        intensity_norm = 1;
    end
    % Loop through pixels and frames and get g2 autocorrelation
    for jj=1:pixels
        for ii=1:frames % Find decorrelation traces
            frame_norm = frames-(ii-1);
            autocorrelation = dot(I_padded(jj,:),circshift(I_padded(jj,:),(ii-1)));
            g2_norm(jj,ii) =  autocorrelation./(frame_norm*(intensity_norm(jj,:)^2));
        end
        disp(jj)
    end

catch ME
    n = ndims(I);
    if n > 2
        msg = append('The current number of dimensions dimensions are ', int2str(n),...
            '. Please convert input to a vector for g2 calculation.');
        causeException = MException('MATLAB:myCode:dimensions', msg);
        ME = addCause(ME, causeException);
    end
    rethrow(ME)

end

% End function
end