function g2_norm = symmetric_g2(speckle)
% computes the symmtric g2
% input must be the 2D array of time series for all pixels e.g. of
% dimensions [pixels, frames].

try
    if max(speckle,[],'all')<256 && isinteger(speckle)==1 % use uint8 if possible for increased speed of fft
        speckle =  uint8(speckle); 
    else
        speckle =  double(speckle);
    end
    % Find autoccorelation through fft with zero padding
    frames = size(speckle,2); % size of time dimension
    fft_I = fft(speckle,frames*2,2); % fft along the time dimension with zero padding
    g2 = real(ifft(fft_I.*conj(fft_I),[],2)); % take the real part of the ifft along time dimension
    g2 = g2(:,1:end/2); % crop out the time dimension extra length from zero padding
    g2_norm = zeros(size(g2));

    % Normalise autocorrelation
    mean_I = mean(speckle,2);
    mean_I2 = mean_I;
    N = frames;
    for ii=1:frames
        if ii==1
            frame_norm = frames-(ii-1);
            intensity_norm = mean_I.*mean_I2;
            g2_norm(:,1) = g2(:,1)./(frame_norm*intensity_norm);
        else
            frame_norm = frames-(ii-1);
            mean_I = ((N-(ii-1)+1)*mean_I-speckle(:,(ii-1)))/(N-(ii-1)); 
            mean_I2 = ((N-(ii-1)+1)*mean_I2-speckle(:,N-(ii-1)))/(N-(ii-1));
            intensity_norm = mean_I.*mean_I2;
            g2_norm(:,ii) = g2(:,ii)./(frame_norm*intensity_norm);
        end
    end
catch ME
    n = ndims(speckle);
    if n > 2
        msg = append('The current number of dimensions dimensions are ', int2str(n),...
            '. Please convert input to a vector for symmetric g2 calculation.');
        causeException = MException('MATLAB:myCode:dimensions', msg);
        ME = addCause(ME, causeException);
    end
    rethrow(ME)
end

%End function
end